//---------------------------------------------------------------------------
// File: TMainForm.cpp, TDx_Draw_Library v1.4, Example2 - Enumerating Devices
//
// Date: 17th May, 2001
// Author: Darren John Dwyer
// Copyright: (c) 2001 Darren John Dwyer, All Rights Reserved.
//
// Description:
//
// This example shows how to Enumerate directdraw devices using the
// TDx_Draw::DDEnumerate() method and the TDx_Draw::OnDDEnumerate() event.
// Once enumerated, it shows how to create and access a particular device,
// and how to destroy the device.
//
//---------------------------------------------------------------------------
#include <vcl\vcl.h>
#pragma hdrstop
//---------------------------------------------------------------------------
#include "TMainForm.h"
//---------------------------------------------------------------------------
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
    #pragma package(smart_init)
#endif
//---------------------------------------------------------------------------
#pragma resource "*.dfm"
//---------------------------------------------------------------------------
#pragma link "TDx_Draw"
#pragma link "TDx_DrawSurface"
#pragma link "TDDCaps"
#pragma link "TDDPixelFormat"
#pragma link "TDDSCaps"
#pragma link "TDDSurfaceDesc"
#pragma link "TDx_Draw_Library_Install"
//---------------------------------------------------------------------------
TMainForm *MainForm;
//---------------------------------------------------------------------------
#define Msg(A)  {\
                if (StatusMemo->Text.Length()>30000) StatusMemo->Text = "";\
                StatusMemo->Lines->Add(A);\
                }
//---------------------------------------------------------------------------
__fastcall TMainForm::TMainForm(TComponent* Owner)
    : TForm(Owner)
{
}
//---------------------------------------------------------------------------
__fastcall TMainForm::~TMainForm()
{
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::FormCreate(TObject *Sender)
{
Width=780;
Height=580;
Position=poScreenCenter;
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::FormDestroy(TObject *Sender)
{
if (Dx_Draw1->Created) Dx_Draw1->Destroy();
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::EnumerateButtonClick(TObject *Sender)
{
Msg("Scanning for Available Devices");

NumDevices = 0;
DevicesListBox->Items->Clear();
Dx_Draw1->DDEnumerate(NULL,0);
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::SelectNextDeviceButtonClick(TObject *Sender)
{
if (DevicesListBox->Items->Count>0)
    {
    Msg("Selecting Next Available Device");
    if (DevicesListBox->ItemIndex==DevicesListBox->Items->Count-1) DevicesListBox->ItemIndex=0;
    else DevicesListBox->ItemIndex = DevicesListBox->ItemIndex + 1;
    DevicesListBox->OnClick(this);
    }
else
    DevicesListBox->ItemIndex = -1;
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::DevicesListBoxClick(TObject *Sender)
{
if (DevicesListBox->ItemIndex!=-1)
    {
    AnsiString name = Names[DevicesListBox->ItemIndex];
    AnsiString desc = Descriptions[DevicesListBox->ItemIndex];

    Msg("Device Selected: '"+name+", "+desc+"'");
    SelectedDeviceLabel->Caption = name;
    }
else
    SelectedDeviceLabel->Caption = "-- none --";
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::CreateSelectedButtonClick(TObject *Sender)
{
if (DevicesListBox->ItemIndex>=0)
    {
    Msg("Creating Selected Device");
    Dx_Draw1->Create( Guids[DevicesListBox->ItemIndex] );
    }
else
    Msg("No Device Selected");
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::RetrieveCapsButtonClick(TObject *Sender)
{
HelCapsListBox->Items->Clear();
DriverCapsListBox->Items->Clear();
Msg("Retrieving Device Capabilities");
if (Dx_Draw1->GetCaps( DriverCaps, HelCaps ))
    {
    // insert caps directly into listboxes
    HelCapsListBox->Items->AddStrings( HelCaps->Caps_Strings );
    DriverCapsListBox->Items->AddStrings( DriverCaps->Caps_Strings );

    // check for particular caps by comparing the 'public:' property using DirectX bitwise flags
    if (DriverCaps->Caps & DDCAPS_3D) Msg("Note: 3D Hardware Acceleration Available");
    if (DriverCaps->Caps & DDCAPS_BANKSWITCHED) Msg("Note: Display is Bank Switched Hardware: Relatively Slow Video Access");
    if (HelCaps->FXCaps & DDFXCAPS_BLTROTATION) Msg("Note: Hardware Emulation Layer supports Hardware Blit Rotation of arbitrary angle." );

    // [OR]
    // check for particular caps by comparing the '__published' property using the vcl's TSet<> operators
    if (DriverCaps->Caps_.Contains(ddcaps_bankswitched)) Msg("Note: Display is Bank Switched Hardware: Relatively Slow Video Access");
    if (DriverCaps->Caps_.Contains(ddcaps_blt)) Msg("Note: Hardware supports Bit-Blitting functions");
    if (HelCaps->FXCaps_.Contains(ddfxcaps_bltrotation90)) Msg("Note: Hardware Emulation Layer supports Hardware Blit Rotation of 90 degrees." );
    }
else
    {
    HelCapsListBox->Items->Add( "------ none ------" );
    DriverCapsListBox->Items->Add( "------ none ------" );
    }
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::DestroyActiveButtonClick(TObject *Sender)
{
Msg("Destroying Currently Active Device");
Dx_Draw1->Destroy();
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::ExitButtonClick(TObject *Sender)
{
Close();
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::ClearDevicesButtonClick(TObject *Sender)
{
if (DevicesListBox->Items->Count>0)
    {
    Msg( "Clearing Available Devices List" );
    DevicesListBox->ItemIndex = -1;
    DevicesListBox->Items->Clear();
    DevicesListBox->OnClick(this);
    }
else
    {
    DevicesListBox->ItemIndex = -1;
    }
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_Draw1Create(TObject *Sender)
{
AnsiString name = Names[DevicesListBox->ItemIndex];
AnsiString desc = Descriptions[DevicesListBox->ItemIndex];

Msg("Device Created: '"+name+", "+desc+"'");
ActiveDeviceLabel->Caption = name;
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_Draw1Destroy(TObject *Sender)
{
AnsiString name = Names[DevicesListBox->ItemIndex];
AnsiString desc = Descriptions[DevicesListBox->ItemIndex];

Msg("Device Destroyed: '"+name+", "+desc+"'");

ActiveDeviceLabel->Caption = "-- none --";
HelCapsListBox->Items->Text = "------ none ------";
DriverCapsListBox->Items->Text = "------ none ------";
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_Draw1Error(TObject *Sender, AnsiString Function,
    AnsiString Error, AnsiString ErrorMessage)
{
Msg("ERROR ["+Error+"]: "+Function+", "+ErrorMessage);
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::Dx_Draw1DDEnumerate(TObject *Sender, GUID *Guid,
    AnsiString DriverDescription, AnsiString DriverName, void *Context,
    HMONITOR HMonitor, bool &Finished)
{
if (NumDevices<MAX_DEVICES)
    {
    Guids[NumDevices] = Guid;
    Names[NumDevices] = DriverName;
    Descriptions[NumDevices] = DriverDescription;
    NumDevices++;

    Msg("Device Found: '"+DriverName+", "+DriverDescription+"'");
    DevicesListBox->Items->Add( DriverName+", "+DriverDescription );
    }
else
    Finished = true;
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::ClearButtonClick(TObject *Sender)
{
StatusMemo->Lines->Clear();
}
//---------------------------------------------------------------------------



