//---------------------------------------------------------------------------
// File: TMainForm.h, TDx_Draw_Library v1.4, Example7 - The Back Buffer
//
// Date: 17th May, 2001
// Author: Darren John Dwyer
// Copyright: (c) 2001 Darren John Dwyer, All Rights Reserved.
//
// Description:
//
// This example creates a 'complex primary surface', then retrieves an
// interface to the 'BackBuffer'.
//
// In order to do this, before creating the TDx_Draw component 'PrimarySurface',
// the example establishes the correct settings for creating a 'complex' primary
// surface.
//
// Then, during the TDx_Draw::OnCreate() event, a surface representing the
// backbuffer is retrieved using TDx_Draw::GetAttachedSurface().
//
// When painting, the example paints directly onto the backbuffer using VCL-style
// code and uses TDx_Draw::Flip() to display the backbuffer content on the monitor.
//
// Lastly, it shows how to destroy the backbuffer / primary surface correctly.
//
//---------------------------------------------------------------------------
#ifndef TMainFormH
#define TMainFormH
//---------------------------------------------------------------------------
#include <vcl\Classes.hpp>
#include <vcl\Controls.hpp>
#include <vcl\StdCtrls.hpp>
#include <vcl\Forms.hpp>
#include <vcl\Buttons.hpp>
#include <vcl\ExtCtrls.hpp>
#include <ComCtrls.hpp>
//---------------------------------------------------------------------------
#include "TDx_Draw.h"
#include "TDx_DrawSurface.h"
#include "TDDCaps.h"
#include "TDDPixelFormat.h"
#include "TDDSCaps.h"
#include "TDDSurfaceDesc.h"
//---------------------------------------------------------------------------

#if (__BORLANDC__ < 0x0530) // BCB Version 1
class TMainForm : public TForm
{
#else // BCB Version 3 +
class PACKAGE TMainForm : public TForm
{
#endif

//---------------------------------------------------------------------------
// Anything that is to be displayed within the Object Inspector
//---------------------------------------------------------------------------
__published:

    TPanel *Panel1;
    TPanel *Panel2;
    TPanel *Panel3;
    TPanel *Panel4;
    TPanel *Panel5;
    TLabel *Label2;
    TLabel *Label3;
    TLabel *Label5;

    TMemo *InfoMemo;
    TMemo *StatusMemo;
    TBitBtn *ExitButton;
    TBitBtn *ClearButton;
    TDx_Draw *Dx_Draw1;
    TListBox *ModesListBox;
    TLabel *Label7;
    TLabel *CurrentModeLabel;
    TLabel *Label1;
    TDx_DrawSurface *PrimarySurface;
    TDDSurfaceDesc *PrimarySurfaceDesc;
    TDDSCaps *PrimaryCaps;
    TButton *PaintButton;
    TButton *RepaintButton;
    TBitBtn *SelectModeButton;
    TBitBtn *NextModeButton;
    TBitBtn *BitBtn2;
    TImage *Image1;
    TButton *FlipButton;
    TDx_DrawSurface *BackBuffer;
    TDDSurfaceDesc *BackBufferDesc;
    TDDSCaps *BackBufferCaps;

    void __fastcall FormCreate(TObject *Sender);
    void __fastcall FormDestroy(TObject *Sender);

    void __fastcall ExitButtonClick(TObject *Sender);
    void __fastcall ClearButtonClick(TObject *Sender);

    void __fastcall Dx_Draw1Create(TObject *Sender);
    void __fastcall Dx_Draw1Destroy(TObject *Sender);
    void __fastcall Dx_Draw1Error(TObject *Sender, AnsiString Function,
    AnsiString Error, AnsiString ErrorMessage);
    void __fastcall Dx_Draw1EnumDisplayModes(TObject *Sender,
          TDDSurfaceDesc *SurfaceDesc, void *Context, bool &Finished);
    void __fastcall NextModeButtonClick(TObject *Sender);
    void __fastcall ModesListBoxClick(TObject *Sender);
    void __fastcall PrimarySurfaceCreate(TObject *Sender);
    void __fastcall PrimarySurfaceDestroy(TObject *Sender);
    void __fastcall PaintButtonClick(TObject *Sender);
    void __fastcall PrimarySurfaceSurfaceLost(TObject *Sender);
    void __fastcall ModesListBoxDblClick(TObject *Sender);
    void __fastcall SelectModeButtonClick(TObject *Sender);
    void __fastcall RepaintButtonClick(TObject *Sender);
    void __fastcall BackBufferCreate(TObject *Sender);
    void __fastcall BackBufferDestroy(TObject *Sender);
    void __fastcall FlipButtonClick(TObject *Sender);
    void __fastcall BitBtn2Click(TObject *Sender);

//---------------------------------------------------------------------------
// Anything available to other classes and/or code
//---------------------------------------------------------------------------
public:

    __fastcall TMainForm(TComponent* Owner);
    virtual __fastcall ~TMainForm();

//---------------------------------------------------------------------------
// Anything available only to classes descended from this class
//---------------------------------------------------------------------------
protected:

//---------------------------------------------------------------------------
// Private data not accessible except from within this class
//---------------------------------------------------------------------------
private:

    #define MAX_MODES 50

    int         Widths[MAX_MODES];
    int         Heights[MAX_MODES];
    int         BitDepths[MAX_MODES];
    int         RefreshRates[MAX_MODES];
    int         NumModes;

};
//---------------------------------------------------------------------------
#if (__BORLANDC__ < 0x0530) // BCB Version 1
extern TMainForm *MainForm;
#else // BCB Version 3 +
extern PACKAGE TMainForm *MainForm;
#endif
//---------------------------------------------------------------------------
#endif

